gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] [gnunet] branch master updated: less heteronormative functi


From: gnunet
Subject: [GNUnet-SVN] [gnunet] branch master updated: less heteronormative function names (SCNR)
Date: Wed, 06 Jun 2018 05:24:08 +0200

This is an automated email from the git hooks/post-receive script.

lynx pushed a commit to branch master
in repository gnunet.

The following commit(s) were added to refs/heads/master by this push:
     new e2d0c3b00 less heteronormative function names (SCNR)
e2d0c3b00 is described below

commit e2d0c3b009e3a52d84d484460210c16072f5d461
Author: psyc://loupsycedyglgamf.onion/~lynX 
<ircs://psyced.org/youbroketheinternet>
AuthorDate: Tue Jun 5 23:11:59 2018 +0000

    less heteronormative function names (SCNR)
---
 po/de.po                                 |  2 +-
 po/es.po                                 |  2 +-
 po/fr.po                                 |  2 +-
 po/sv.po                                 |  2 +-
 po/vi.po                                 |  2 +-
 po/zh_CN.po                              |  2 +-
 src/cadet/gnunet-service-cadet_tunnels.c | 12 ++++++------
 src/core/gnunet-service-core_kx.c        |  4 ++--
 8 files changed, 14 insertions(+), 14 deletions(-)

diff --git a/po/de.po b/po/de.po
index b3eff360d..b43617412 100644
--- a/po/de.po
+++ b/po/de.po
@@ -1340,7 +1340,7 @@ msgstr "# verschlüsselter PONG Nachrichten empfangen"
 #: src/core/gnunet-service-core_kx.c:1054
 #, c-format
 msgid ""
-"EPHERMAL_KEY from peer `%s' rejected as its validity range does not match "
+"EPHEMERAL_KEY from peer `%s' rejected as its validity range does not match "
 "our system time (%llu not in [%llu,%llu]).\n"
 msgstr ""
 
diff --git a/po/es.po b/po/es.po
index 2bd5655fb..1fdd8f54d 100644
--- a/po/es.po
+++ b/po/es.po
@@ -1421,7 +1421,7 @@ msgstr "# mensajes «SET_KEY» descifrados"
 #: src/core/gnunet-service-core_kx.c:1054
 #, c-format
 msgid ""
-"EPHERMAL_KEY from peer `%s' rejected as its validity range does not match "
+"EPHEMERAL_KEY from peer `%s' rejected as its validity range does not match "
 "our system time (%llu not in [%llu,%llu]).\n"
 msgstr ""
 
diff --git a/po/fr.po b/po/fr.po
index a18337c11..3541215e8 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -1313,7 +1313,7 @@ msgstr ""
 #: src/core/gnunet-service-core_kx.c:1054
 #, c-format
 msgid ""
-"EPHERMAL_KEY from peer `%s' rejected as its validity range does not match "
+"EPHEMERAL_KEY from peer `%s' rejected as its validity range does not match "
 "our system time (%llu not in [%llu,%llu]).\n"
 msgstr ""
 
diff --git a/po/sv.po b/po/sv.po
index d6f9dfe28..a512b655d 100644
--- a/po/sv.po
+++ b/po/sv.po
@@ -1363,7 +1363,7 @@ msgstr "# PING-meddelanden skapade"
 #: src/core/gnunet-service-core_kx.c:1054
 #, c-format
 msgid ""
-"EPHERMAL_KEY from peer `%s' rejected as its validity range does not match "
+"EPHEMERAL_KEY from peer `%s' rejected as its validity range does not match "
 "our system time (%llu not in [%llu,%llu]).\n"
 msgstr ""
 
diff --git a/po/vi.po b/po/vi.po
index 7303a5176..8d8b9f144 100644
--- a/po/vi.po
+++ b/po/vi.po
@@ -1371,7 +1371,7 @@ msgstr "# các thông báo được chắp liền"
 #: src/core/gnunet-service-core_kx.c:1054
 #, c-format
 msgid ""
-"EPHERMAL_KEY from peer `%s' rejected as its validity range does not match "
+"EPHEMERAL_KEY from peer `%s' rejected as its validity range does not match "
 "our system time (%llu not in [%llu,%llu]).\n"
 msgstr ""
 
diff --git a/po/zh_CN.po b/po/zh_CN.po
index cc98cc49e..4e77d8c08 100644
--- a/po/zh_CN.po
+++ b/po/zh_CN.po
@@ -1341,7 +1341,7 @@ msgstr ""
 #: src/core/gnunet-service-core_kx.c:1054
 #, c-format
 msgid ""
-"EPHERMAL_KEY from peer `%s' rejected as its validity range does not match "
+"EPHEMERAL_KEY from peer `%s' rejected as its validity range does not match "
 "our system time (%llu not in [%llu,%llu]).\n"
 msgstr ""
 
diff --git a/src/core/gnunet-service-core_kx.c 
b/src/core/gnunet-service-core_kx.c
index 21f1308f7..1f1a47677 100644
--- a/src/core/gnunet-service-core_kx.c
+++ b/src/core/gnunet-service-core_kx.c
@@ -1051,7 +1051,7 @@ handle_ephemeral_key (void *cls,
        (start_t.abs_value_us > GNUNET_TIME_absolute_add (now, 
REKEY_TOLERANCE).abs_value_us) )
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-               _("EPHERMAL_KEY from peer `%s' rejected as its validity range 
does not match our system time (%llu not in [%llu,%llu]).\n"),
+               _("EPHEMERAL_KEY from peer `%s' rejected as its validity range 
does not match our system time (%llu not in [%llu,%llu]).\n"),
                GNUNET_i2s (kx->peer),
                (unsigned long long) now.abs_value_us,
                 (unsigned long long) start_t.abs_value_us,
@@ -1490,7 +1490,7 @@ send_key (struct GSC_KeyExchangeInfo *kx)
                         sizeof (current_ekm.ephemeral_key),
                         &hc);
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                "Sending EPHERMERAL_KEY %s to `%s' (my status: %d)\n",
+                "Sending EPHEMERAL_KEY %s to `%s' (my status: %d)\n",
                 GNUNET_h2s (&hc),
                 GNUNET_i2s (kx->peer),
                 kx->status);

diff --git a/src/cadet/gnunet-service-cadet_tunnels.c 
b/src/cadet/gnunet-service-cadet_tunnels.c
index 5c52eb616..ef6f97622 100644
--- a/src/cadet/gnunet-service-cadet_tunnels.c
+++ b/src/cadet/gnunet-service-cadet_tunnels.c
@@ -459,13 +459,13 @@ struct CadetTunnel
 
 
 /**
  * Am I Alice or Bob, or talking to myself?
  *
  * @param other the other peer
- * @return #GNUNET_YES for Alice, #GNUNET_NO for Bob, #GNUNET_SYSERR if 
talking to myself
+ * @return #GNUNET_YES for Alice, #GNUNET_NO for Betty, #GNUNET_SYSERR if 
talking to myself
  */
 static int
-alice_or_bob (const struct GNUNET_PeerIdentity *other)
+alice_or_betty (const struct GNUNET_PeerIdentity *other)
 {
   if (0 > GNUNET_CRYPTO_cmp_peer_identity (&my_full_id,
                                            other))
@@ -1347,7 +1347,7 @@ send_kx (struct CadetTunnel *t,
   struct GNUNET_CADET_TunnelKeyExchangeMessage *msg;
   enum GNUNET_CADET_KX_Flags flags;
 
-  if (GNUNET_YES != alice_or_bob (GCP_get_id (t->destination)))
+  if (GNUNET_YES != alice_or_betty (GCP_get_id (t->destination)))
     return; /* only Alice may send KX */
   if ( (NULL == ct) ||
        (GNUNET_NO == ct->is_ready) )
@@ -1523,7 +1523,7 @@ update_ax_by_kx (struct CadetTunnelAxolotl *ax,
   const char salt[] = "CADET Axolotl salt";
   int am_I_alice;
 
-  if (GNUNET_SYSERR == (am_I_alice = alice_or_bob (pid)))
+  if (GNUNET_SYSERR == (am_I_alice = alice_or_betty (pid)))
   {
     GNUNET_break_op (0);
     return GNUNET_SYSERR;
@@ -1726,7 +1726,7 @@ GCT_handle_kx (struct CadetTConnection *ct,
                             1,
                             GNUNET_NO);
   if (GNUNET_YES ==
-      alice_or_bob (GCP_get_id (t->destination)))
+      alice_or_betty (GCP_get_id (t->destination)))
   {
     /* Bob is not allowed to send KX! */
     GNUNET_break_op (0);
@@ -459,13 +459,13 @@ struct CadetTunnel
 
 /**
- * Am I Alice or Bob, or talking to myself?
+ * Am I Alice or Betty (some call her Bob), or talking to myself?
  *
  * @param other the other peer
-- 
To stop receiving notification emails like this one, please contact
address@hidden



reply via email to

[Prev in Thread] Current Thread [Next in Thread]